function X=solvediag(A,B)
% FUNCTION solvediag
% -- X=solvediag(A,B)
%     Solve the linear systems A*X=B  where A is N-by-d-by-d regular diagonal 
%     amat object and B is either a N-by-d-by-n amat object or a d-by-n 
%     matrix.
%     The ouput X is a  N-by-d-by-n amat object which satisfies:
%        for all k in 1:N
%             A(k)*X(k)=B(k)  if B is an  amat object
%             A(k)*X(k)=B     if B is a matrix
%
  assert(isamat(A));
  [N,m,n]=size(A);
  assert( m==n, '1st parameter must be a square amat object')
  [dimA,dimB]=fc_amat.getDimensions(A,B);
  assert( dimA(3)==dimB(2) );
  N=dimA(1);d=dimA(2);m=dimB(3);
  getB=fc_amat.getVec(B,N);
  X=fc_amat.zeros(N,d,m);
  for i=1:d
    for l=1:m
      X.values(:,i,l)=A.values(:,i,i).\getB(B,i,l);
    end  
  end
end
